@@ -1,9 +1,9 @@
 from logging import getLogger
-from os import EX_OK, EX_USAGE
-from os.path import isdir, isfile
-from warnings import warn
+from os import EX_OK, EX_USAGE, EX_OSERR
+from os.path import isdir
 from typing import Optional, Tuple, List
 
+import vnet_manager.operations.machine as machine_op
 from vnet_manager.conf import settings
 from vnet_manager.config.config import get_config
 from vnet_manager.config.validate import ValidateConfig
@@ -13,14 +13,6 @@ from vnet_manager.utils.files import write_file_to_disk, get_yaml_files_from_dis
 from vnet_manager.environment.lxc import ensure_vnet_lxc_environment, cleanup_vnet_lxc_environment
 from vnet_manager.operations.image import destroy_lxc_image
 from vnet_manager.operations.files import put_files_on_machine, generate_vnet_hosts_file, place_vnet_hosts_file_on_machines
-from vnet_manager.actions.help import display_help_for_action
-from vnet_manager.operations.machine import (
-    show_status,
-    change_machine_status,
-    create_machines,
-    destroy_machines,
-    enable_type_specific_machine_configuration,
-)
 from vnet_manager.operations.interface import (
     bring_up_vnet_interfaces,
     bring_down_vnet_interfaces,
@@ -38,7 +30,17 @@ class ActionManager:
     Use this class to initiate specific VNet action in a controlled manner
     """
 
-    def __init__(self, config_path: str = None, sniffer: bool = False, base_image: bool = False, no_hosts: bool = False):
+    def __init__(
+        self,
+        config_path: Optional[str] = None,
+        machines: Optional[List[str]] = None,
+        sniffer: bool = False,
+        base_image: bool = False,
+        no_hosts: bool = False,
+        purge: bool = False,
+        pcap_dir: str = settings.VNET_SNIFFER_PCAP_DIR,
+        provider: str = "lxc",
+    ):
         """
         :param str config_path: The path to the config
         :param bool sniffer: Whether to enable sniffers on 'start'
@@ -49,48 +51,30 @@ class ActionManager:
         self.sniffer = sniffer
         self.base_image = base_image
         self.no_hosts = no_hosts
-        self._machines = None
+        self.provider = provider
+        self.machines = machines
+        self.purge = purge
+        self.pcap_dir = pcap_dir
         self._config_validated = False
 
-    @property
-    def machines(self) -> Optional[List[str]]:
-        return self._machines
-
-    @machines.setter
-    def machines(self, machines: List[str]):
-        """
-        Only preform actions on a certain amount of machines.
-        Note that this only applies to the machine actions, all general actions will ignore this value.
-        :param list machines: The machine names to preform actions on, defaults to all
-        """
-        self._machines = machines
-
     def execute(self, action: str) -> int:
         """
         Execute an action
         :param str action: The name of the action to execute
-        :raises NotImplementedError: If the action is unknown
-        :raises RuntimeError
         :return: int: returncode of the action
         """
         # First do a sanity check on the action
-        if action not in settings.VALID_ACTIONS:
-            raise NotImplementedError(f"{action} is not a valid action")
-        # Check if the operator only wants to see the help text
-        if self.config_path and self.config_path.lower() == "help":
-            display_help_for_action(action)
-            return EX_OK
-        # Check if a config is required
-        if action in settings.CONFIG_REQUIRED_ACTIONS:
-            if not self.config_path:
-                raise RuntimeError(f"The {action} action requires a config to be passed, but it wasn't")
-            if not self.parse_config():
-                logger.critical("Config NOT OK, can't proceed")
-                return EX_USAGE
+        action_func = action.replace("-", "_")
+        if not hasattr(self, f"preform_{action_func}_action"):
+            logger.critical(f"{action} is not a valid action")
+            return EX_USAGE
+        if self.config_path and action not in ("connect", "list") and not self.parse_config():
+            logger.critical("Config NOT OK, can't proceed")
+            return EX_USAGE
         # Preform the action
         logger.info(f"Initiating {action} action")
-        getattr(self, f"preform_{action.replace('-', '_')}_action")()
-        return EX_OK
+        # Return the exit code provided by the execute function or exit EX_OK if no exit code is provided
+        return getattr(self, f"preform_{action_func}_action")() or EX_OK
 
     def parse_config(self) -> bool:
         """
@@ -122,28 +106,37 @@ class ActionManager:
         return True, validator.updated_config
 
     def preform_show_action(self):
-        show_status(self.config)
+        machine_op.show_status(self.config)
         show_vnet_interface_status(self.config)
         if "veths" in self.config:
             show_vnet_veth_interface_status(self.config)
 
     def preform_start_action(self):
-        bring_up_vnet_interfaces(self.config, sniffer=self.sniffer)
-        change_machine_status(self.config, machines=self._machines, status="start")
+        bring_up_vnet_interfaces(self.config, sniffer=self.sniffer, pcap_dir=self.pcap_dir)
+        machine_op.change_machine_status(self.config, machines=self.machines, status="start")
 
     def preform_stop_action(self):
-        change_machine_status(self.config, machines=self._machines, status="stop")
+        machine_op.change_machine_status(self.config, machines=self.machines, status="stop")
         # If specific machines are specified, we don't want to mess with the interfaces
-        if self._machines:
+        if self.machines:
             logger.warning("Not bringing down VNet interfaces as we are only stopping specific machines, this may leave lingering sniffers")
         else:
             bring_down_vnet_interfaces(self.config)
 
+    def preform_connect_action(self):
+        # Make the provider exists
+        if self.provider not in settings.PROVIDERS.keys():
+            logger.error(f"Provider {self.provider} not supported")
+            return EX_USAGE
+        # Connect to it
+        getattr(machine_op, f"connect_to_{self.provider}_machine")(self.config_path)
+        return EX_OK
+
     def preform_create_action(self):
         # Make sure the provider environments are correct
         ensure_vnet_lxc_environment(self.config)
         # Make the machines
-        create_machines(self.config, machines=self._machines)
+        machine_op.create_machines(self.config, machines=self.machines)
         # Put user requested file on the machines
         put_files_on_machine(self.config)
         if not self.no_hosts:
@@ -151,16 +144,18 @@ class ActionManager:
             generate_vnet_hosts_file(self.config)
             place_vnet_hosts_file_on_machines(self.config)
         # Configure type specific stuff
-        enable_type_specific_machine_configuration(self.config)
+        machine_op.enable_type_specific_machine_configuration(self.config)
 
     def preform_destroy_action(self):
-        if self.base_image:
+        if self.purge:
+            self.preform_purge_action()
+        elif self.base_image:
             request_confirmation(prompt="Are you sure you want to delete the VNet base images (y/n)? ")
             destroy_lxc_image(settings.LXC_BASE_IMAGE_ALIAS, by_alias=True)
         else:
-            destroy_machines(self.config, machines=self._machines)
+            machine_op.destroy_machines(self.config, machines=self.machines)
             # If specific machines are specified, we don't want to mess with the interfaces
-            if self._machines:
+            if self.machines:
                 logger.warning(
                     "Not deleting VNet interfaces as we are only destroying specific machines, this may leave lingering sniffers"
                 )
@@ -168,25 +163,18 @@ class ActionManager:
                 delete_vnet_interfaces(self.config)
 
     def preform_list_action(self):
-        # First check if we have been passed a file or directory
-        if isfile(self.config_path):
-            dep_msg = "List action with a regular config file is deprecated, use the 'show' action instead"
-            logger.warning(dep_msg)
-            warn(dep_msg)
-            # Execute the show action instead
-            self.execute("show")
-        elif isdir(self.config_path):
-            # We exclude the default.yaml config file because it is not a valid user config
-            yaml_files = get_yaml_files_from_disk_path(self.config_path)
-            for path in yaml_files:
-                self.config_path = path
-                if not self.parse_config():
-                    logger.error(f"Config {path} does not seem to be a valid config, skipping")
-                    continue
-                logger.info(f"Showing machine status for {path}")
-                show_status(self.config)
-        else:
-            logger.error(f"Path {self.config_path} does not seem to be a file or a directory, did you forget to pass a config directory?")
+        if not isdir(self.config_path):
+            logger.error(f"Provided path {self.config_path} does not seem to be a directory")
+            return EX_OSERR
+        yaml_files = get_yaml_files_from_disk_path(self.config_path)
+        for path in yaml_files:
+            self.config_path = path
+            if not self.parse_config():
+                logger.error(f"Config {path} does not seem to be a valid config, skipping")
+                continue
+            logger.info(f"Showing machine status for {path}")
+            machine_op.show_status(self.config)
+        return EX_OK
 
     @staticmethod
     def preform_version_action():
@@ -199,5 +187,5 @@ class ActionManager:
         logger.info("Bash completion generated and placed. Use ' . /etc/bash_completion' to load in this terminal")
 
     @staticmethod
-    def preform_clean_action():
+    def preform_purge_action():
         cleanup_vnet_lxc_environment()
