@@ -18,20 +18,33 @@ def main(args: Sequence = None) -> int:
     :param list args: The pre-cooked arguments to pass to the ArgParser
     :return int: exit_code
     """
-    args = parse_vnet_args(args)
+    args = vars(parse_vnet_args(args))
     # Set the VNET_FORCE variable, if --yes is given this will answer yes to all questions
-    environ[settings.VNET_FORCE_ENV_VAR] = "true" if args.yes else "false"
+    environ[settings.VNET_FORCE_ENV_VAR] = "true" if args.get("yes") else "false"
     # Setup logging
-    setup_console_logging(verbosity=get_logging_verbosity(args))
+    setup_console_logging(verbosity=get_logging_verbosity(verbose=args["verbose"], quite=args["quite"]))
     # Most VNet operation require root. So, do a root check
     if not check_for_root_user():
         logger.critical("This program should only be run as root")
         return EX_NOPERM
+    # Silence the unknown attribute warnings from PyLXD
+    environ["PYLXD_WARNINGS"] = "none"
     # Let the action manager handle the rest
-    manager = ActionManager(config_path=args.config, sniffer=args.sniffer, base_image=args.base_image, no_hosts=args.no_hosts)
-    if args.machines:
-        manager.machines = args.machines
-    return manager.execute(args.action)
+    manager = ActionManager(
+        config_path=args.get("config"),
+        sniffer=args.get("sniffer", False),
+        base_image=args.get("base_image", False),
+        no_hosts=args.get("no_hosts", False),
+        purge=args.get("purge", False),
+        provider=args.get("provider"),
+        pcap_dir=args.get("pcap_dir", settings.VNET_SNIFFER_PCAP_DIR),
+    )
+    if args.get("machines"):
+        manager.machines = args["machines"]
+    # Status is renamed to show to make sure we execute the right action
+    if args["action"] == "status":
+        args["action"] = "show"
+    return manager.execute(args["action"])
 
 
 if __name__ == "__main__":
